import axios from 'axios';
import { ref } from 'vue';

import useLoading from '@/hooks/loading';

export interface OptionListItem {
  value: number;
  label: string;
}
type TransformType = (item: Record<string, any>) => OptionListItem;

type ConfigItem = string | { url: string; transform?: TransformType };

const defaultTransform = (item: {
  id: number;
  name: string;
}): OptionListItem => ({
  value: item.id,
  label: item.name,
});

export type SelectType = 'problemType' | 'rejectType';

const selectConfig: Record<SelectType, ConfigItem> = {
  // 问题卷分类
  problemType: '/api/admin/exam/problem/type/list',
  // 打回卷分类
  rejectType: '/api/admin/exam/reject/type/find',
};

export default function useSearch(type: SelectType) {
  const { loading, setLoading } = useLoading();
  const optionList = ref<OptionListItem[]>([]);

  async function search(params?: Record<string, any>) {
    if (loading.value) return;
    const config = selectConfig[type];
    if (!config) {
      console.error('下拉列表类型错误！');
      return;
    }

    try {
      setLoading(true);
      let url = '';
      let transform = defaultTransform;
      if (typeof config === 'string') {
        url = config;
      } else {
        url = config.url;
        transform = config.transform || defaultTransform;
      }
      const res = (await axios.post(url, {}, { params })) as Array<
        Record<string, any>
      >;

      optionList.value = res.map(transform);
    } catch (error) {
      console.error(error);
    } finally {
      setLoading(false);
    }
  }

  return {
    loading,
    optionList,
    search,
  };
}
